@@ -1621,7 +1621,7 @@ class Connections(object):
 						"net_id":net_id,
 					}
 		return r3sponse.success_response(f"Successfully listed {len(connections)} ssh connection(s).", {
-			connections:connections,
+			"connections":connections,
 		})
 # Initialized classes.
 installation = Installation()
